@@ -7,9 +7,11 @@ from twisted.scripts.twistd import run
 def main():
     target_dir = os.path.dirname(os.path.abspath(__file__))
 
-    pid_file = "/var/run/bo-webservice.pid"
+    args = ["twistd"]
+    if not os.environ.get("BLITZORTUNG_TEST"):
+        args += ["--pidfile", "/var/run/bo-webservice.pid"]
 
-    sys.argv = ["twistd", "--pidfile", pid_file, "-oy", os.path.join(target_dir, "webservice.py")]
+    sys.argv = args + ["-oy", os.path.join(target_dir, "webservice.py")]
     sys.exit(run())
 
 
